==> opensearch-dashboards-2.11.1.tgz: opensearch-dashboards/src/core/server/saved_objects/service/lib/priority_collection.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PriorityCollection = void 0;

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
class PriorityCollection {
  constructor() {
    _defineProperty(this, "array", []);
  }

  add(priority, value) {
    const foundIndex = this.array.findIndex(current => {
      if (priority === current.priority) {
        throw new Error('Already have entry with this priority');
      }

      return priority < current.priority;
    });
    const spliceIndex = foundIndex === -1 ? this.array.length : foundIndex;
    this.array.splice(spliceIndex, 0, {
      priority,
      value
    });
  }

  has(predicate) {
    return this.array.some(entry => predicate(entry.value));
  }

  toPrioritizedArray() {
    return this.array.map(entry => entry.value);
  }

}

exports.PriorityCollection = PriorityCollection;

==> opensearch-dashboards-3.4.0.tgz: opensearch-dashboards/src/core/server/saved_objects/service/lib/priority_collection.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PriorityCollection = void 0;
function _defineProperty(e, r, t) { return (r = _toPropertyKey(r)) in e ? Object.defineProperty(e, r, { value: t, enumerable: !0, configurable: !0, writable: !0 }) : e[r] = t, e; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == typeof i ? i : i + ""; }
function _toPrimitive(t, r) { if ("object" != typeof t || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != typeof i) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
/*
 * SPDX-License-Identifier: Apache-2.0
 *
 * The OpenSearch Contributors require contributions made to
 * this file be licensed under the Apache-2.0 license or a
 * compatible open source license.
 *
 * Any modifications Copyright OpenSearch Contributors. See
 * GitHub history for details.
 */

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

class PriorityCollection {
  constructor() {
    _defineProperty(this, "array", []);
  }
  add(priority, value) {
    const foundIndex = this.array.findIndex(current => {
      if (priority === current.priority) {
        throw new Error('Already have entry with this priority');
      }
      return priority < current.priority;
    });
    const spliceIndex = foundIndex === -1 ? this.array.length : foundIndex;
    this.array.splice(spliceIndex, 0, {
      priority,
      value
    });
  }
  has(predicate) {
    return this.array.some(entry => predicate(entry.value));
  }
  toPrioritizedArray() {
    return this.array.map(entry => entry.value);
  }
}
exports.PriorityCollection = PriorityCollection;
